@@ -18,6 +18,7 @@ import math
 import datetime
 import forecast
 import noaa
+import time
 from collections import Counter
 from geopy import geocoders
 
@@ -31,6 +32,11 @@ class resultSet(object):
         self.annualOutput = 0
         self.clippingHours = 0
 
+    def dump(self):
+        return (self.timeseries, self.values)
+    def dumps(self):
+        return ([int(time.mktime(i.timetuple())) for i in self.timeseries],self.values)
+
     def plot(self):
         import matplotlib.pyplot as plt
         import matplotlib.dates as mdates
@@ -312,18 +318,19 @@ class system(object):
             tModule = irradiation.moduleTemp(irradiance, weatherData)
             return self.Pac(irradiance, tModule)
 
-    def powerToday(self, daylightSavings = False, source = None):
+    def forecastOutput(self, daylightSavings = False, source = None, hours = 24):
+    #def powerToday(self, daylightSavings = False, source = None, hours = 24):
         #default is forecast with solpy.blave 
         #this is ugly code... sorry
+        d = datetime.date.today()
+        endTimeUTC = datetime.datetime(d.year,d.month,d.day)\
+                + datetime.timedelta(hours=hours-self.tz)
         if source == 'noaa':
             wseries = noaa.herpDerpInterp(self.place)
             ts = []
             irr = []
-            d = datetime.date.today()
-            tomorrowMidnightUTC = datetime.datetime(d.year,d.month,d.day)\
-                        + datetime.timedelta(days=2,hours=-self.tz)
             for i in wseries:
-                if i['utc_datetime'] > tomorrowMidnightUTC:
+                if i['utc_datetime'] > endTimeUTC:
                     break
                 rec = irradiation.blave(i['utc_datetime'],self.place, \
                         self.tilt, self.azimuth, cloudCover = i['cloudCover'])
@@ -342,11 +349,8 @@ class system(object):
             wseries = forecast.hourly(self.place)
             ts = []
             irr = []
-            d = datetime.date.today()
-            tomorrowMidnightUTC = datetime.datetime(d.year,d.month,d.day)\
-                        + datetime.timedelta(days=2,hours=-self.tz)
             for i in wseries:
-                if i['utc_datetime'] > tomorrowMidnightUTC:
+                if i['utc_datetime'] > endTimeUTC:
                     break
                 irradiance = irradiation.irradiation(i,self.place,\
                         t=self.tilt, array_azimuth=self.azimuth, model='p90')
@@ -363,11 +367,8 @@ class system(object):
             wseries = forecast.hourly(self.place)
             ts = []
             irr = []
-            d = datetime.date.today()
-            tomorrowMidnightUTC = datetime.datetime(d.year,d.month,d.day)\
-                        + datetime.timedelta(days=2,hours=-self.tz)
             for i in wseries:
-                if i['utc_datetime'] > tomorrowMidnightUTC:
+                if i['utc_datetime'] > endTimeUTC:
                     break
                 rec = irradiation.blave(i['utc_datetime'],self.place, \
                         self.tilt, self.azimuth, cloudCover = i['cloudCover'])
