@@ -15,17 +15,17 @@ p1 = """{"system_name":"HAPPY CUSTOMER",
             }
             ]}"""
 plant = pv.jsonToSystem(json.loads(p1))
-b = plant.powerToday(source = 'blave')
+b = plant.forecastOutput(source = 'blave')
 print b.values
 print len(b.values)
 print  sum(b.values)
 
-f = plant.powerToday(source = 'forecast')
+f = plant.forecastOutput(source = 'forecast')
 print f.values
 print len(f.values)
 print  sum(f.values)
 
-n = plant.powerToday(source = 'noaa')
+n = plant.forecastOutput(source = 'noaa')
 print n.values
 print len(n.values)
 print  sum(n.values)
